@@ -20,6 +20,7 @@
 
 #include <config.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 #include <glib/gstdio.h>
 #include <gio/gio.h>
@@ -55,7 +56,7 @@
 #define ANJUTA_PIXMAP_BUILD            "anjuta-build"
 #define ANJUTA_STOCK_BUILD             "anjuta-build"
 
-#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-build-basic-autotools-plugin.ui"
+#define UI_FILE PACKAGE_DATA_DIR"/ui/anjuta-build-basic-autotools-plugin.xml"
 #define MAX_BUILD_PANES 3
 #define PREF_INDICATORS_AUTOMATIC "indicators.automatic"
 #define PREF_INSTALL_ROOT "build.install.root"
@@ -941,7 +942,7 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 			context->locations = g_slist_prepend (context->locations, loc);
 			
 			/* If current editor file is same as indicator file, set indicator */
-			if (anjuta_preferences_get_int (anjuta_shell_get_preferences (context->plugin->shell, NULL), PREF_INDICATORS_AUTOMATIC))
+			if (anjuta_preferences_get_bool (anjuta_shell_get_preferences (context->plugin->shell, NULL), PREF_INDICATORS_AUTOMATIC))
 			{
 				build_indicator_location_set (loc, p->current_editor,
 											  p->current_editor_filename);
@@ -1046,6 +1047,7 @@ on_build_terminated (AnjutaLauncher *launcher,
 							   _("Command terminated for an unknown reason"));
 		}
 		build_program_callback (context->program, G_OBJECT (context->plugin), context, err);
+		if (err != NULL) g_error_free (err);
 	}
 	if (context->used)
 		return;	/* Another command is run */
@@ -1240,6 +1242,7 @@ build_get_context (BasicAutotoolsPlugin *plugin, const gchar *dir,
 {
 	BuildContext *context = NULL;
 	AnjutaPluginManager *plugin_manager;
+	gchar *buf;
 
 	if (with_view)
 	{
@@ -1276,35 +1279,18 @@ build_get_context (BasicAutotoolsPlugin *plugin, const gchar *dir,
 	g_signal_connect (G_OBJECT (context->launcher), "child-exited",
 					  G_CALLBACK (on_build_terminated), context);
 	build_context_push_dir (context, "default", dir);
-	dir = g_strconcat (dir, "/", NULL);
-	g_chdir (dir);
+	buf = g_strconcat (dir, "/", NULL);
+	g_chdir (buf);
+	g_free (buf);
 	
 	plugin->contexts_pool = g_list_append (plugin->contexts_pool, context);
 	
 	return context;
 }
 
-/* Save all current anjuta files */
-static void
-save_all_files (AnjutaPlugin *plugin)
-{
-	IAnjutaDocumentManager *docman;
-	IAnjutaFileSavable* save;
-
-	docman = anjuta_shell_get_interface (plugin->shell, IAnjutaDocumentManager, NULL);
-	/* No document manager, so no file to save */
-	if (docman != NULL)
-	{
-		save = IANJUTA_FILE_SAVABLE (docman);
-		if (save) ianjuta_file_savable_save (save, NULL);
-	}
-}
-
 static void
 build_set_command_in_context (BuildContext* context, BuildProgram *prog)
 {
-	if (context->program != NULL)
-		build_program_free (context->program);
 	context->program = prog;
 	context->used = TRUE;
 }
@@ -1317,17 +1303,17 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	/* Send options to make */
 	if (strcmp (build_program_get_basename (context->program), "make") == 0)
 	{
-		if (!anjuta_preferences_get_int (prefs , PREF_TRANSLATE_MESSAGE))
+		if (!anjuta_preferences_get_bool (prefs , PREF_TRANSLATE_MESSAGE))
 		{
 			build_program_add_env (context->program, "LANGUAGE", "C");
 		}
-		if (anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE))
+		if (anjuta_preferences_get_bool (prefs , PREF_PARALLEL_MAKE))
 		{
 			gchar *arg = g_strdup_printf ("-j%d", anjuta_preferences_get_int (prefs , PREF_PARALLEL_MAKE_JOB));
 			build_program_insert_arg (context->program, 1, arg);
 			g_free (arg);
 		}
-		if (anjuta_preferences_get_int (prefs , PREF_CONTINUE_ON_ERROR))
+		if (anjuta_preferences_get_bool (prefs , PREF_CONTINUE_ON_ERROR))
 		{
 			build_program_insert_arg (context->program, 1, "-k");
 		}
@@ -1335,9 +1321,6 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 	
 	build_program_override (context->program, context->environment);
 	
-	/* Add current directory */
-	build_program_add_env (context->program, "PWD", context->program->work_dir);
-	
 	if (context->message_view)
 	{
 		gchar *command;
@@ -1352,21 +1335,75 @@ build_execute_command_in_context (BuildContext* context, GError **err)
 		g_free (command);
 	
 		anjuta_launcher_execute_v (context->launcher,
-								   context->program->argv,
-								   context->program->envp,
-								   on_build_mesg_arrived, context);
+		    context->program->work_dir,
+		    context->program->argv,
+		    context->program->envp,
+		    on_build_mesg_arrived, context);
 	}
 	else
 	{
 		anjuta_launcher_execute_v (context->launcher,
-								   context->program->argv,
-								   context->program->envp,
-								   NULL, NULL);
+		    context->program->work_dir,
+		    context->program->argv,
+		    context->program->envp,
+		    NULL, NULL);
 	}		
 	
 	return TRUE;
 }	
 
+static void
+build_delayed_execute_command (IAnjutaFileSavable *savable, GFile *file, gpointer user_data)
+{
+	BuildContext *context = (BuildContext *)user_data;
+
+	if (savable != NULL)
+	{
+		g_signal_handlers_disconnect_by_func (savable, G_CALLBACK (build_delayed_execute_command), user_data); 
+		context->file_saved--;
+	}	
+	
+	if (context->file_saved == 0)
+	{
+		build_execute_command_in_context (context, NULL);
+	}
+}
+
+static gboolean
+build_save_and_execute_command_in_context (BuildContext* context, GError **err)
+{
+	IAnjutaDocumentManager *docman;
+
+	context->file_saved = 0;
+	
+	docman = anjuta_shell_get_interface (context->plugin->shell, IAnjutaDocumentManager, NULL);
+	/* No document manager, so no file to save */
+	if (docman != NULL)
+	{
+		GList *doc_list = ianjuta_document_manager_get_doc_widgets (docman, NULL);
+		GList *node;
+
+		for (node = g_list_first (doc_list); node != NULL; node = g_list_next (node))
+		{
+			if (IANJUTA_IS_FILE_SAVABLE (node->data))
+			{
+				IAnjutaFileSavable* save = IANJUTA_FILE_SAVABLE (node->data);
+				if (ianjuta_file_savable_is_dirty (save, NULL))
+				{
+					context->file_saved++;
+					g_signal_connect (G_OBJECT (save), "saved", G_CALLBACK (build_delayed_execute_command), context);
+					ianjuta_file_savable_save (save, NULL);
+				}
+			}
+		}
+		g_list_free (doc_list);		
+	}
+	
+	build_delayed_execute_command (NULL, NULL, context);
+
+	return TRUE;
+}
+
 static gchar *
 build_dir_from_source (BasicAutotoolsPlugin *plugin, const gchar *src_dir)
 {
@@ -1407,60 +1444,81 @@ build_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
 	}
 }
 
-static void
-build_delayed_execute_command (IAnjutaFileSavable *savable, GFile *file, gpointer user_data)
-{
-	BuildContext *context = (BuildContext *)user_data;
-
-	if (savable != NULL)
-	{
-		g_signal_handlers_disconnect_by_func (savable, G_CALLBACK (build_delayed_execute_command), user_data); 
-		context->file_saved--;
-	}	
-	
-	if (context->file_saved == 0)
-	{
-		build_execute_command_in_context (context, NULL);
-	}
-}
-
 static BuildContext*
 build_save_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
 								gboolean with_view, GError **err)
 {
-	AnjutaPlugin* plugin = ANJUTA_PLUGIN(bplugin);
 	BuildContext *context;
-	IAnjutaDocumentManager *docman;
+	
+	context = build_get_context (bplugin, prog->work_dir, with_view);
+
+	build_set_command_in_context (context, prog);
+	if (!build_save_and_execute_command_in_context (context, err))
+	{
+		build_context_destroy (context);
+		context = NULL;
+	}
+
+	return context;
+}
+
+static void
+build_execute_after_command (GObject *sender,
+							   IAnjutaBuilderHandle handle,
+							   GError *error,
+							   gpointer user_data)
+{
+	BuildProgram *prog = (BuildProgram *)user_data;
+	BuildContext *context = (BuildContext *)handle;
+
+	/* Try next command even if the first one fail (make distclean return an error) */
+	if ((error == NULL) || (error->code != IANJUTA_BUILDER_ABORTED))
+	{
+		build_set_command_in_context (context, prog);
+		build_execute_command_in_context (context, NULL);
+	}
+	else
+	{
+		build_program_free (prog);
+	}
+}
+
+static BuildContext*
+build_save_distclean_and_execute_command (BasicAutotoolsPlugin* bplugin, BuildProgram *prog,
+								gboolean with_view, GError **err)
+{
+	BuildContext *context;
 
 	context = build_get_context (bplugin, prog->work_dir, with_view);
-	build_set_command_in_context (context, prog);
-	context->file_saved = 0;
-
-	docman = anjuta_shell_get_interface (plugin->shell, IAnjutaDocumentManager, NULL);
-	/* No document manager, so no file to save */
-	if (docman != NULL)
+	
+	if ((strcmp (prog->work_dir, bplugin->project_root_dir) != 0) && directory_has_file (bplugin->project_root_dir, "config.status"))
 	{
-		GList *doc_list = ianjuta_document_manager_get_doc_widgets (docman, NULL);
-		GList *node;
-
-		for (node = g_list_first (doc_list); node != NULL; node = g_list_next (node))
+		BuildProgram *new_prog;
+		
+		// Need to run make clean before
+		if (!anjuta_util_dialog_boolean_question (GTK_WINDOW (ANJUTA_PLUGIN (bplugin)->shell), _("Using this new configuration, need to to remove the default one. Do you want to do it ?"), NULL))
 		{
-			if (IANJUTA_IS_FILE_SAVABLE (node->data))
-			{
-				IAnjutaFileSavable* save = IANJUTA_FILE_SAVABLE (node->data);
-				if (ianjuta_file_savable_is_dirty (save, NULL))
-				{
-					context->file_saved++;
-					g_signal_connect (G_OBJECT (save), "saved", G_CALLBACK (build_delayed_execute_command), context);
-					ianjuta_file_savable_save (save, NULL);
-				}
-			}
+			GError *err;
+			
+			err = g_error_new (ianjuta_builder_error_quark (),
+									 IANJUTA_BUILDER_CANCELED,
+									 _("Command canceled by user"));
+			
+			build_program_callback (context->program, G_OBJECT (bplugin), context, err);
+			
+			return NULL;
 		}
-		g_list_free (doc_list);		
+		new_prog = build_program_new_with_command (bplugin->project_root_dir,
+										   "%s",
+										   CHOOSE_COMMAND (bplugin, DISTCLEAN));
+		build_program_set_callback (new_prog, build_execute_after_command, prog);
+		prog = new_prog;
 	}
 	
-	build_delayed_execute_command (NULL, NULL, context);
-	
+	build_set_command_in_context (context, prog);
+
+	build_save_and_execute_command_in_context (context, NULL);
+
 	return context;
 }
 
@@ -1565,7 +1623,7 @@ get_root_install_command(BasicAutotoolsPlugin *bplugin)
 {
 	AnjutaPlugin* plugin = ANJUTA_PLUGIN(bplugin);
 	AnjutaPreferences* prefs = anjuta_shell_get_preferences (plugin->shell, NULL);
-	if (anjuta_preferences_get_int (prefs , PREF_INSTALL_ROOT))
+	if (anjuta_preferences_get_bool (prefs , PREF_INSTALL_ROOT))
 	{
 		gchar* command = anjuta_preferences_get(prefs, PREF_INSTALL_ROOT_COMMAND);
 		if (command != NULL)
@@ -1792,7 +1850,7 @@ build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const g
 {
 	BuildContext *context;
 	BuildProgram *prog;
-	BuildConfigureAndBuild *pack = g_new(BuildConfigureAndBuild, 1);
+	BuildConfigureAndBuild *pack = g_new0 (BuildConfigureAndBuild, 1);
 
 	
 	prog = build_program_new_with_command (dirname,
@@ -1806,7 +1864,7 @@ build_configure_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const g
 	pack->name = g_strdup (name);
 	build_program_set_callback (prog, build_project_configured, pack);
 	
-	context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
+	context = build_save_distclean_and_execute_command (plugin, prog, TRUE, NULL);
 	
 	return context;
 }
@@ -1837,7 +1895,7 @@ build_configure_after_autogen (GObject *sender,
 		{
 			gboolean older;
 			
-			filename = g_build_filename (context->program->work_dir, "config.log", NULL);
+			filename = g_build_filename (context->program->work_dir, "config.status", NULL);
 			older =(stat (filename, &log_stat) != 0) || (log_stat.st_mtime < conf_stat.st_mtime);
 			g_free (filename);
 			
@@ -1882,7 +1940,7 @@ build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gc
 {
 	BuildContext *context;
 	BuildProgram *prog;
-	BuildConfigureAndBuild *pack = g_new (BuildConfigureAndBuild, 1);
+	BuildConfigureAndBuild *pack = g_new0 (BuildConfigureAndBuild, 1);
 	
 	if (directory_has_file (plugin->project_root_dir, "autogen.sh"))
 	{
@@ -1905,7 +1963,7 @@ build_generate_dir (BasicAutotoolsPlugin *plugin, const gchar *dirname, const gc
 	pack->name = g_strdup (name);
 	build_program_set_callback (prog, build_configure_after_autogen, pack);
 	
-	context = build_save_and_execute_command (plugin, prog, TRUE, NULL);
+	context = build_save_distclean_and_execute_command (plugin, prog, TRUE, NULL);
 	
 	return context;
 }
@@ -1917,16 +1975,19 @@ build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gcha
 	gboolean run_autogen = FALSE;
 	const gchar *project_root;
 	GValue value = {0,};
+	const gchar *old_config_name;
 	
 	run_autogen = !directory_has_file (plugin->project_root_dir, "configure");
 	
 	anjuta_shell_get_value (ANJUTA_PLUGIN (plugin)->shell, IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, &value, NULL);
 	project_root = g_value_get_string (&value);
 	parent = GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell);
-	
+
+	old_config_name = build_configuration_get_name (build_configuration_list_get_selected (plugin->configurations));
 	if (build_dialog_configure (parent, project_root, plugin->configurations, &run_autogen))
 	{
 		BuildConfiguration *config;
+		BuildContext* context;
 		GFile *file;
 		gchar *uri;
 		gchar *build_dir;
@@ -1944,13 +2005,19 @@ build_configure_dialog (BasicAutotoolsPlugin *plugin, BuildFunc func, const gcha
 		
 		if (run_autogen)
 		{
-			build_generate_dir (plugin, build_dir, args, func, name);
+			context = build_generate_dir (plugin, build_dir, args, func, name);
 		}
 		else
 		{
-			build_configure_dir (plugin, build_dir, args, func, name);
+			context = build_configure_dir (plugin, build_dir, args, func, name);
 		}
 		g_free (build_dir);
+
+		if (context == NULL)
+		{
+			/* Restore previous configuration */
+			build_configuration_list_select (plugin->configurations, old_config_name);
+		}
 	}
 	
 }
@@ -1998,6 +2065,44 @@ build_configure_and_build (BasicAutotoolsPlugin *plugin, BuildFunc func, const g
 	}
 }
 
+/* Configuration commands
+ *---------------------------------------------------------------------------*/
+
+static GList*
+build_list_configuration (BasicAutotoolsPlugin *plugin)
+{
+	BuildConfiguration *cfg;
+	GList *list = NULL;
+	
+	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
+	{
+		const gchar *name = build_configuration_get_name (cfg);
+
+		if (name != NULL) list = g_list_prepend (list, (gpointer)name);
+	}
+
+	return list;
+}
+
+static const gchar*
+build_get_uri_configuration (BasicAutotoolsPlugin *plugin, const gchar *uri)
+{
+	BuildConfiguration *cfg;
+	
+	for (cfg = build_configuration_list_get_first (plugin->configurations); cfg != NULL; cfg = build_configuration_next (cfg))
+	{
+		const gchar *root = build_configuration_list_get_build_uri  (plugin->configurations, cfg);
+
+		if (strncmp (uri, root, strlen (root)) == 0)
+		{
+			return build_configuration_get_name (cfg);
+		}
+	}
+
+	return NULL;
+}
+
+
 /* User actions
  *---------------------------------------------------------------------------*/
 
@@ -2841,7 +2946,7 @@ on_update_indicators_idle (gpointer data)
 	/* If indicators are not yet updated in the editor, do it */
 	if (ba_plugin->current_editor_filename &&
 		IANJUTA_IS_INDICABLE (editor) &&
-		anjuta_preferences_get_int (anjuta_shell_get_preferences (plugin->shell,
+		anjuta_preferences_get_bool (anjuta_shell_get_preferences (plugin->shell,
 																  NULL),
 									PREF_INDICATORS_AUTOMATIC))
 	{
@@ -3347,57 +3452,70 @@ ibuilder_cancel (IAnjutaBuilder *builder, IAnjutaBuilderHandle handle, GError **
 	build_cancel_command (plugin, (BuildContext *)handle, err);
 }
 
+static GList*
+ibuilder_list_configuration (IAnjutaBuilder *builder, GError **err)
+{
+	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (builder);
+
+	return build_list_configuration (plugin);
+}
+
+static const gchar*
+ibuilder_get_uri_configuration (IAnjutaBuilder *builder, const gchar *uri, GError **err)
+{
+	BasicAutotoolsPlugin *plugin = ANJUTA_PLUGIN_BASIC_AUTOTOOLS (builder);
+
+	return build_get_uri_configuration (plugin, uri);
+}
+
 static void
 ibuilder_iface_init (IAnjutaBuilderIface *iface)
 {
 	iface->is_built = ibuilder_is_built;
 	iface->build = ibuilder_build;
 	iface->cancel = ibuilder_cancel;
+	iface->list_configuration = ibuilder_list_configuration;
+	iface->get_uri_configuration = ibuilder_get_uri_configuration;
 }
 
 /* IAnjutaPreferences implementation
  *---------------------------------------------------------------------------*/
 
-static GladeXML *gxml;
-
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
 	GtkWidget *root_check;
-	GtkWidget *entry;
+	GtkWidget *make_check;
+	GtkWidget *root_entry;
+	GtkWidget *make_entry;
+	GtkBuilder *bxml;
 		
 	/* Create the preferences page */
-	gxml = glade_xml_new (GLADE_FILE, BUILD_PREFS_DIALOG, NULL);
-	root_check = glade_xml_get_widget(gxml, INSTALL_ROOT_CHECK);
-	entry = glade_xml_get_widget(gxml, INSTALL_ROOT_ENTRY);
-	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), entry);
-	on_root_check_toggled (root_check, entry);
-	root_check = glade_xml_get_widget(gxml, PARALLEL_MAKE_CHECK);
-	entry = glade_xml_get_widget(gxml, PARALLEL_MAKE_SPIN);
-	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), entry);
-	on_root_check_toggled (root_check, entry);
+	bxml =  anjuta_util_builder_new (BUILDER_FILE, NULL);
+	if (!bxml) return;
+
+	anjuta_util_builder_get_objects (bxml,
+	    INSTALL_ROOT_CHECK, &root_check,
+	    INSTALL_ROOT_ENTRY, &root_entry,
+	    PARALLEL_MAKE_CHECK, &make_check,
+	    PARALLEL_MAKE_SPIN, &make_entry,
+	    NULL);
 	
-	anjuta_preferences_add_page (prefs, gxml, BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
+	g_signal_connect(G_OBJECT(root_check), "toggled", G_CALLBACK(on_root_check_toggled), root_entry);
+	on_root_check_toggled (root_check, root_entry);
+
+	g_signal_connect(G_OBJECT(make_check), "toggled", G_CALLBACK(on_root_check_toggled), make_entry);
+	on_root_check_toggled (make_check, make_entry);
+	
+	anjuta_preferences_add_from_builder (prefs, bxml, BUILD_PREFS_ROOT, _("Build Autotools"),  ICON_FILE);
+	
+	g_object_unref (bxml);
 }
 
 static void
 ipreferences_unmerge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
-	GtkWidget *root_check;
-	GtkWidget *entry;
-
-	root_check = glade_xml_get_widget(gxml, INSTALL_ROOT_CHECK);
-	entry = glade_xml_get_widget(gxml, INSTALL_ROOT_ENTRY);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
-		G_CALLBACK(on_root_check_toggled), entry);
-	root_check = glade_xml_get_widget(gxml, PARALLEL_MAKE_CHECK);
-	entry = glade_xml_get_widget(gxml, PARALLEL_MAKE_SPIN);
-	g_signal_handlers_disconnect_by_func(G_OBJECT(root_check),
-		G_CALLBACK(on_root_check_toggled), entry);
-		
 	anjuta_preferences_remove_page(prefs, _("Build Autotools"));
-	
-	g_object_unref (gxml);
 }
 
 static void
