@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef PLUGIN_H
@@ -27,9 +27,9 @@
 #include <libanjuta/interfaces/ianjuta-message-manager.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 
-#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-cvs-plugin.glade"
+#define GLADE_FILE PACKAGE_DATA_DIR"/glade/anjuta-cvs-plugin.ui"
 
-extern GType cvs_plugin_get_type (AnjutaGluePlugin *plugin);
+extern GType cvs_plugin_get_type (GTypeModule *module);
 #define ANJUTA_TYPE_PLUGIN_CVS         (cvs_plugin_get_type (NULL))
 #define ANJUTA_PLUGIN_CVS(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), ANJUTA_TYPE_PLUGIN_CVS, CVSPlugin))
 #define ANJUTA_PLUGIN_CVS_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), ANJUTA_TYPE_PLUGIN_CVS, CVSPluginClass))
