@@ -26,7 +26,9 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib.h>
+#include <gdk/gdk.h>
 
 /*#define DEBUG*/
 #include <libanjuta/anjuta-debug.h>
@@ -176,7 +178,7 @@ create_memory_gui (DmaMemory *mem)
 	anjuta_shell_add_widget (mem->plugin->shell,
 							 mem->window,
                              "AnjutaDebuggerMemory", _("Memory"),
-                             NULL, ANJUTA_SHELL_PLACEMENT_CENTER,
+                             NULL, ANJUTA_SHELL_PLACEMENT_NONE,
 							 NULL);
 	
 	return TRUE;
