@@ -142,6 +142,42 @@ git_check_input (GtkWidget *parent, GtkWidget *widget, const gchar *input,
 	return ret;
 }
 
+gboolean
+git_get_selected_stash (GtkTreeSelection *selection, gchar **stash)
+{
+	gboolean ret;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GtkWidget *stash_view;
+	GtkWidget *parent;
+	GtkWidget *dialog;
+
+	ret = FALSE;
+	*stash = NULL;
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	{
+		gtk_tree_model_get (model, &iter, 0, stash, -1);
+		ret = TRUE;
+	}
+	else
+	{
+		stash_view = GTK_WIDGET (gtk_tree_selection_get_tree_view (selection));
+		parent = gtk_widget_get_toplevel (stash_view);
+		dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+										 GTK_DIALOG_DESTROY_WITH_PARENT,
+										 GTK_MESSAGE_WARNING,
+										 GTK_BUTTONS_OK,
+										 "%s", _("Please select a stash"));
+
+		gtk_dialog_run (GTK_DIALOG (dialog));
+		gtk_widget_destroy (dialog);
+	}
+	
+
+	return ret;
+}
+
 gchar * 
 git_get_log_from_textview (GtkWidget* textview)
 {
@@ -371,6 +407,31 @@ on_git_list_branch_combo_command_data_arrived (AnjutaCommand *command,
 	}
 }
 
+/* This function is used for selection lists. */
+void
+on_git_list_branch_command_data_arrived (AnjutaCommand *command,
+										 GtkListStore *branch_list_model)
+{
+	GQueue *output_queue;
+	GitBranch *branch;
+	GtkTreeIter iter;
+	gchar *name;
+	
+	output_queue = git_branch_list_command_get_output (GIT_BRANCH_LIST_COMMAND (command));
+
+	while (g_queue_peek_head (output_queue))
+	{
+		branch = g_queue_pop_head (output_queue);
+		name = git_branch_get_name (branch);
+
+		gtk_list_store_append (branch_list_model, &iter);
+		gtk_list_store_set (branch_list_model, &iter, 1, name, -1);
+		
+		g_object_unref (branch);
+		g_free (name);
+	}
+}
+
 void
 on_git_list_branch_combo_command_finished (AnjutaCommand *command, 
                                            guint return_code,
@@ -382,6 +443,93 @@ on_git_list_branch_combo_command_finished (AnjutaCommand *command,
 	g_object_unref (command);
 }
 
+
+void
+on_git_list_tag_command_data_arrived (AnjutaCommand *command,
+                              		  GtkListStore *tag_list_model)
+{
+	GQueue *output_queue;
+	gchar *tag_name;
+	GtkTreeIter iter;
+	
+	output_queue = git_raw_output_command_get_output (GIT_RAW_OUTPUT_COMMAND (command));
+	
+	while (g_queue_peek_head (output_queue))
+	{
+		tag_name = g_queue_pop_head (output_queue);
+
+		gtk_list_store_append (tag_list_model, &iter);
+		gtk_list_store_set (tag_list_model, &iter, 1, tag_name, -1);
+		
+		g_free (tag_name);
+	}
+}
+
+void
+on_git_list_stash_command_data_arrived (AnjutaCommand *command,
+										GtkListStore *stash_list_model)
+{
+	GQueue *output_queue;
+	GitStash *stash;
+	GtkTreeIter iter;
+	gchar *id;
+	gchar *message;
+	guint number;
+	
+	output_queue = git_stash_list_command_get_output (GIT_STASH_LIST_COMMAND (command));
+
+	while (g_queue_peek_head (output_queue))
+	{
+		stash = g_queue_pop_head (output_queue);
+		id = git_stash_get_id (stash);
+		message = git_stash_get_message (stash);
+		number = git_stash_get_number (stash);
+
+		gtk_list_store_append (stash_list_model, &iter);
+		gtk_list_store_set (stash_list_model, &iter, 
+							0, id,
+							1, message,
+		                    2, number,
+							-1);
+		
+		g_object_unref (stash);
+		g_free (id);
+		g_free (message);
+	}
+}
+
+void
+on_git_stash_save_command_finished (AnjutaCommand *command, guint return_code,
+									Git *plugin)
+{
+	AnjutaStatus *status;
+	
+	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell,
+									  NULL);
+	
+	anjuta_status (status, _("Git: Changes stored in a stash."), 5);
+	
+	git_report_errors (command, return_code);
+	
+	g_object_unref (command);
+}
+
+void
+on_git_stash_apply_command_finished (AnjutaCommand *command, guint return_code,
+									 Git *plugin)
+{
+	AnjutaStatus *status;
+	
+	status = anjuta_shell_get_status (ANJUTA_PLUGIN (plugin)->shell,
+									  NULL);
+	
+	anjuta_status (status, _("Git: Stashed changes applied."), 5);
+	
+	git_report_errors (command, return_code);
+	
+	g_object_unref (command);
+}
+
 void
 git_select_all_status_items (GtkButton *select_all_button,
 							 AnjutaVcsStatusTreeView *tree_view)
@@ -521,3 +669,38 @@ git_cancel_data_arrived_signal_disconnect (AnjutaCommand *command,
 						 (GWeakNotify) git_disconnect_data_arrived_signals,
 						 command);
 }
+
+
+gboolean
+git_get_selected_refs (GtkTreeModel *model, GtkTreePath *path, 
+					   GtkTreeIter *iter, GList **selected_list)
+{
+	gboolean selected;
+	gchar *name;
+
+	gtk_tree_model_get (model, iter, 
+						0, &selected,
+						1, &name,
+						-1);
+
+	if (selected)
+		*selected_list = g_list_append (*selected_list, name);
+
+	return FALSE;
+}
+
+void
+on_git_selected_column_toggled (GtkCellRendererToggle *renderer, gchar *path,
+								GtkListStore *list_store)
+{
+	GtkTreeIter iter;
+	gboolean selected;
+
+	gtk_tree_model_get_iter_from_string (GTK_TREE_MODEL (list_store), &iter, 
+										 path);
+
+	gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter, 0, &selected, -1);
+	
+	gtk_list_store_set (list_store, &iter, 0, !selected, -1);
+	
+}
