@@ -33,6 +33,7 @@
 #include "git-status-command.h"
 #include "git-diff-command.h"
 #include "git-branch-list-command.h"
+#include "git-stash-list-command.h"
 
 typedef struct
 {
@@ -54,6 +55,7 @@ void git_progress_data_free (GitProgressData *data);
 void git_create_message_view (Git* plugin);
 gboolean git_check_input (GtkWidget *parent, GtkWidget *widget,  
 						  const gchar *input, const gchar *error_message);
+gboolean git_get_selected_stash (GtkTreeSelection *selection, gchar **stash);
 gchar *git_get_log_from_textview (GtkWidget* textview);
 guint git_status_bar_progress_pulse (Git *plugin, gchar *text);
 void git_clear_status_bar_progress_pulse (guint timer_id);
@@ -78,6 +80,14 @@ void on_git_list_branch_command_data_arrived (AnjutaCommand *command,
 void on_git_list_branch_combo_command_finished (AnjutaCommand *command,
                                                 guint return_code,
                                                 GtkComboBox *combo_box);
+void on_git_list_tag_command_data_arrived (AnjutaCommand *command, 
+									   GtkListStore *tag_list_model);
+void on_git_list_stash_command_data_arrived (AnjutaCommand *command,
+											 GtkListStore *stash_list_model);
+void on_git_stash_save_command_finished (AnjutaCommand *command, 
+										 guint return_code, Git *plugin);
+void on_git_stash_apply_command_finished (AnjutaCommand *command,
+										  guint return_code, Git *plugin);
 void git_select_all_status_items (GtkButton *select_all_button, 
 								  AnjutaVcsStatusTreeView *tree_view);
 void git_clear_all_status_selections (GtkButton *clear_button,
