@@ -62,10 +62,14 @@ struct _Git
 	
 	GtkWidget *log_viewer;
 	GtkWidget *log_popup_menu;
+	GtkWidget *stash_widget;
+	GtkWidget *stash_widget_grip;
 	
 	/* File monitors */
 	GFileMonitor *bisect_file_monitor;
+	GFileMonitor *log_branch_refresh_monitor;
 	GFileMonitor *log_refresh_monitor;
+	GFileMonitor *stash_refresh_monitor;
 };
 
 struct _GitClass
