@@ -653,6 +653,7 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter)
 			if (name != NULL)
 			{
 				const gchar* args = ianjuta_symbol_get_args(symbol, NULL);
+				const gchar* rettype = ianjuta_symbol_get_returntype (symbol, NULL);
 				gchar* print_args;
 				gchar* separator;
 				gchar* white_name = g_strnfill (strlen(name) + 1, ' ');
@@ -666,8 +667,11 @@ cpp_java_assist_create_calltips (IAnjutaIterable* iter)
 				
 				argv = g_strsplit (args, ",", -1);
 				print_args = g_strjoinv (separator, argv);
+
+				if (!rettype)
+					rettype = "";
 				
-				gchar* tip = g_strdup_printf ("%s %s", name, print_args);
+				gchar* tip = g_strdup_printf ("%s %s %s", rettype, name, print_args);
 				
 				if (!g_list_find_custom (tips, tip, (GCompareFunc) strcmp))
 					tips = g_list_append (tips, tip);
@@ -818,7 +822,8 @@ cpp_java_assist_check (CppJavaAssist *assist, gboolean autocomplete,
 		{
 			if (ianjuta_editor_assist_tip_shown (IANJUTA_EDITOR_ASSIST (editor), NULL))
 			{
-				if (!g_str_equal (call_context, assist->priv->calltip_context))
+				if (assist->priv->calltip_context &&
+				    !g_str_equal (call_context, assist->priv->calltip_context))
 				{
 					cpp_java_assist_show_calltip (assist, call_context,
 					                              iter);
