@@ -55,8 +55,8 @@ symbol_db_engine_find_symbol_by_name_pattern (SymbolDBEngine *dbe,
  * @param exact_match Should the pattern be searched for an exact match?
  * @param filter_kinds Can be NULL. In that case these filters will not be taken into consideration.
  * @param include_kinds Should the filter_kinds (if not null) be applied as inluded or excluded?
- * @param global_symbols_search If TRUE only global public function will be searched. If false
- *		  even private or static (for C language) will be searched.
+ * @param global_symbols_search If 1 only global public function will be searched. If 0
+ *		  even private or static (for C language) will be searched. -1 to be ignored.
  * @param session_projects Should the search, a global search, be filtered by some packages (projects)?
  *        If yes then provide a GList, if no then pass NULL.	 
  * @param results_limit Limit results to an upper bound. -1 If you don't want to use this par.
@@ -69,13 +69,23 @@ symbol_db_engine_find_symbol_by_name_pattern_filtered (SymbolDBEngine *dbe,
 									gboolean exact_match,
 									const GPtrArray *filter_kinds,
 									gboolean include_kinds,
-									gboolean global_symbols_search,
+									gint global_symbols_search,
 									GList *session_projects,													   
 									gint results_limit, 
 									gint results_offset,
 									SymExtraInfo sym_info);
 
 
+SymbolDBEngineIterator *
+symbol_db_engine_find_symbol_by_name_pattern_on_file (SymbolDBEngine *dbe,
+									const gchar *pattern,
+									const gchar *full_local_file_path,
+									const GPtrArray *filter_kinds,
+									gboolean include_kinds,
+									gint results_limit,
+									gint results_offset,
+									SymExtraInfo sym_info);
+
 /**
  * Return an iterator to the data retrieved from database. 
  * The iterator, if not null, will contain a list of parent classes for the 
@@ -100,7 +110,8 @@ symbol_db_engine_get_class_parents_by_symbol_id (SymbolDBEngine *dbe,
  */
 SymbolDBEngineIterator *
 symbol_db_engine_get_current_scope (SymbolDBEngine *dbe, 
-									const gchar* full_local_file_path, gulong line, 
+									const gchar* full_local_file_path, 
+    								gulong line, 
 									SymExtraInfo sym_info);
 
 
@@ -143,6 +154,45 @@ symbol_db_engine_get_parent_scope_id_by_symbol_id (SymbolDBEngine *dbe,
 									gint scoped_symbol_id,
 									const gchar* db_file);
 
+/**
+ * Walk the path up to the root scope given a scoped_symbol_id parameter.
+ * The returned iterator will be populated with SymbolDBEngineIteratorNode(s)
+ * so that it could be easily browsed by a client app.
+ *
+ * e.g.
+ * namespace FooBase {
+ * class FooKlass {
+ *	
+ * }
+ *
+ * void FooKlass::foo_func () {			<-------------- this is the scoped symbol
+ *              
+ * }
+ * 
+ * the returned iterator'll contain symbols in this order: foo_func, FooKlass, FooBase.
+ *
+ * @return NULL on error or if scope isn't found.
+ */
+SymbolDBEngineIterator *
+symbol_db_engine_get_scope_chain (SymbolDBEngine *dbe,
+    								gint scoped_symbol_id,
+    								const gchar* db_file,
+    								SymExtraInfo sym_info);
+
+/**
+ * Walk the path up to the root scope given a full_local_file_path and a line number.
+ * The returned iterator will be populated with SymbolDBEngineIteratorNode(s)
+ * so that it could be easily browsed by a client app.
+ *
+ * @return NULL on error or if scope isn't found.
+ */
+SymbolDBEngineIterator *
+symbol_db_engine_get_scope_chain_by_file_line (SymbolDBEngine *dbe,
+									const gchar* full_local_file_path, 
+    								gulong line,
+    								SymExtraInfo sym_info);
+
+
 /** 
  * scope_path cannot be NULL.
  * scope_path will be something like "scope1_kind", "scope1_name", "scope2_kind", 
@@ -168,7 +218,7 @@ symbol_db_engine_get_scope_members_by_symbol_id (SymbolDBEngine *dbe,
 
 /**
  * A filtered version of the symbol_db_engine_get_scope_members_by_symbol_id ().
- * You can specify which kind of symbols to retrieve, and if include them or exclude.
+ * You can specify which kind of symbols to retrieve, and if to include them or exclude.
  * Kinds are 'namespace', 'class' etc.
  * @param filter_kinds cannot be NULL.
  * @param results_limit Limit results to an upper bound. -1 If you don't want to use this par.
