@@ -49,7 +49,7 @@ symbol_db_glist_compare_func (gconstpointer a, gconstpointer b);
  * User must care to free the returned string.
  * @param db_file Relative path inside project.
  */
-gchar*
+gchar *
 symbol_db_util_get_full_local_path (SymbolDBEngine *dbe, const gchar* db_file);
 
 /**
@@ -57,14 +57,14 @@ symbol_db_util_get_full_local_path (SymbolDBEngine *dbe, const gchar* db_file);
  * /home/user/foo_project/src/foo.c returned file should be /src/foo.c.
  * Return NULL on error.
  */
-gchar*
+gchar *
 symbol_db_util_get_file_db_path (SymbolDBEngine *dbe, const gchar* full_local_file_path);
 
 /** 
  * Hash table that converts from a char like 'class' 'struct' etc to an 
  * IANJUTA_SYMBOL_TYPE
  */
-const GHashTable*
+const GHashTable *
 symbol_db_util_get_sym_type_conversion_hash (SymbolDBEngine *dbe);
 
 /**
@@ -86,7 +86,7 @@ symbol_db_util_get_files_with_zero_symbols (SymbolDBEngine *dbe);
  * @return The pixbufs. It will initialize pixbufs first if they weren't before
  * @param node_access can be NULL.
  */
-const GdkPixbuf* 
+const GdkPixbuf *
 symbol_db_util_get_pixbuf  (const gchar *node_type, const gchar *node_access);
 
 /**
@@ -98,4 +98,14 @@ symbol_db_util_get_pixbuf  (const gchar *node_type, const gchar *node_access);
 gboolean
 symbol_db_util_is_pattern_exact_match (const gchar *pattern);
 
+/**
+ * This function gets all the .c/.h source files in the specified dir and returns
+ * the GPtrArray associated.
+ * 
+ * @param dir Directory of the files
+ * @return A GPtrArray composed by gchar * strings like "dir + g_file_info_get_name ()"
+ */
+GPtrArray * 
+symbol_db_util_get_c_source_files (const gchar* dir);
+
 #endif
